﻿/* ItemCommentViewModelTest.cs
 * part of zaaReloaded2
 * 
 * Copyright 2015 Daniel Kraus
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using NUnit.Framework;
using zaaReloaded2.Controller.Comments;
using zaaReloaded2.ViewModels;

namespace Tests.ViewModels
{
    [TestFixture]
    class ItemCommentViewModelTest
    {
        [Test]
        public void Properties()
        {
            ItemComment comment = new ItemComment("item", "pre", "val", "suf");
            ItemCommentViewModel vm = new ItemCommentViewModel(comment);
            Assert.AreEqual(comment.Item, vm.Item);
            Assert.AreEqual(comment.Prefix, vm.Prefix);
            Assert.AreEqual(comment.Suffix, vm.Suffix);
            Assert.AreEqual(comment.Value, vm.Value);
        }

        [Test]
        public void EnterComment()
        {
            ItemComment comment = new ItemComment("TAC", "(Ziel-Talspiegel: ", "", "µg/l)");
            ItemCommentViewModel vm = new ItemCommentViewModel(comment);
            vm.Value = "8-10";
            bool eventRaised = false;
            vm.RequestCloseView += (sender, args) =>
            {
                eventRaised = true;
            };
            vm.SaveCommand.Execute(null);
            Assert.IsTrue(eventRaised, "Event was not raised.");
            Assert.IsFalse(comment.IsCancelled, "Comment.IsCancelled should be false");
            Assert.AreEqual("8-10", comment.Value);
        }

        [Test]
        public void CancelComment()
        {
            ItemComment comment = new ItemComment("TAC", "(Ziel-Talspiegel: ", "default", "µg/l)");
            ItemCommentViewModel vm = new ItemCommentViewModel(comment);
            vm.Value = "blabla";
            bool eventRaised = false;
            vm.RequestCloseView += (sender, args) =>
            {
                eventRaised = true;
            };
            vm.CloseViewCommand.Execute(null);
            Assert.IsTrue(eventRaised, "Event was not raised.");
            Assert.IsTrue(comment.IsCancelled, "Comment.IsCancelled should be true");
            Assert.AreEqual("default", comment.Value);
        }
    }
}
