﻿/* SettingsRepositoryViewModel.cs
 * part of zaaReloaded2
 * 
 * Copyright 2015 Daniel Kraus
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using NUnit.Framework;
using zaaReloaded2.Controller;
using zaaReloaded2.ViewModels;

namespace Tests.ViewModels
{
    [TestFixture]
    class SettingsRepositoryViewModelTest
    {
        SettingsRepositoryViewModel _vm;
        const string TESTNAME = "hello world";

        [SetUp]
        public void SetUp()
        {
            SettingsRepository rep = new SettingsRepository();
            rep.SettingsList.Add(new Settings(TESTNAME));
            _vm = new SettingsRepositoryViewModel(rep);
        }

        [Test]
        public void CanDeleteNonDefaultSettings()
        {
            _vm.SettingsList[_vm.SettingsList.Count - 1].IsSelected = true;
            Assert.IsTrue(_vm.DeleteSettingsCommand.CanExecute(null));
        }

        [Test]
        public void CannotDeleteDefaultSettings()
        {
            _vm.SettingsList[0].IsSelected = true;
            Assert.IsFalse(_vm.DeleteSettingsCommand.CanExecute(null));
        }

        [Test]
        public void CopySettings()
        {
            SettingsViewModel orig = _vm.SettingsList[0];
            orig.IsSelected = true;
            _vm.CopySettingsCommand.Execute(null);
            SettingsViewModel copy = _vm.SettingsList[_vm.SettingsList.Count-1];

            // Make sure we have a new object
            Assert.AreNotSame(orig, copy);
            Assert.AreNotSame(orig.RevealModelObject(), copy.RevealModelObject());

            Assert.AreEqual(
                String.Format(
                    "Kopie von {0}",
                    orig.Name.Replace(" (eingebaut)", String.Empty)
                ),
                copy.Name);
            Assert.IsTrue(copy.IsSelected);
        }
    }
}
