﻿/* Text.cs
 * part of zaaReloaded2
 * 
 * Copyright 2015 Daniel Kraus
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
using System;
using System.Collections.Generic;
using System.Linq;
using System.Runtime.Serialization;
using System.Text;

namespace zaaReloaded2.Controller.Elements
{
    /// <summary>
    /// Controller element that writes arbitrary text to the document.
    /// </summary>
    [Serializable]
    public class CustomText : FormatElementBase, ISerializable
    {
        public override string Label
        {
            get
            {
                if (String.IsNullOrEmpty(Content))
                {
                    return "Beliebiger Text";
                }
                else
                {
                    return String.Format("\"{0}\"", Content);
                }
            }
        }

        public override void Run(Formatter.Formatter formatter)
        {
            formatter.WriteParagraph(Content);
        }

        protected override ElementBase CreateInstance()
        {
            CustomText clone = new CustomText();
            clone.Content = Content;
            return clone;
        }

        #region Constructors

        public CustomText () { }
    
        /// <summary>
        /// Deserialization constructor.
        /// </summary>
        protected CustomText(SerializationInfo info, StreamingContext context)
        {
            int version = info.GetInt32("Version");
            Content = info.GetString("Content");
        }

        #endregion
    }
}
