﻿/* ElementBase.cs
 * part of zaaReloaded2
 * 
 * Copyright 2015 Daniel Kraus
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Office.Interop.Word;
using zaaReloaded2.LabModel;
using System.Runtime.Serialization;

namespace zaaReloaded2.Controller.Elements
{
    /// <summary>
    /// Base class for formatting elements.
    /// </summary>
    public abstract class ElementBase : ICloneable
    {
        /// <summary>
        /// Returns the label for this formatting element.
        /// </summary>
        abstract public string Label { get; }

        /// <summary>
        /// Executes the action described by this formatting element.
        /// For example, an Items element Writes the laboratory items
        /// listed in its Line property to a Word document.
        /// </summary>
        /// <param name="formatter">Formatter object that this
        /// Element belongs to. The Formatter object provides access
        /// to the current Word document etc.</param>
        abstract public void Run(zaaReloaded2.Formatter.Formatter formatter);

        public object Clone()
        {
            return CreateInstance();
        }

        /// <summary>
        /// Creates a new instance that can be used for cloning.
        /// </summary>
        /// <returns>New instance of a derived class.</returns>
        protected abstract ElementBase CreateInstance();
    }
}
