﻿/* FormatElementBase.cs
 * part of zaaReloaded2
 * 
 * Copyright 2015 Daniel Kraus
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Runtime.Serialization;
namespace zaaReloaded2.Controller.Elements
{
    /// <summary>
    /// Base class for elements that perform actual formatting.
    /// </summary>
    public abstract class FormatElementBase : ElementBase, ISerializable
    {
        /// <summary>
        /// Gets or sets the content of this format element.
        /// </summary>
        public string Content
        {
            get { return _content; }
            set
            {
                _content = value;
            }
        }

        /// <summary>
        /// Is called whenever the Content is changed.
        /// </summary>
        protected virtual void OnContentChanged() {}

        private string _content;
        
        #region Serialization

        public virtual void GetObjectData(SerializationInfo info, StreamingContext context)
        {
            info.AddValue("Version", Properties.Settings.Default.SerializationVersion);
            info.AddValue("Content", Content);
        }

        #endregion
    }
}
