﻿/* AbnormalStyle.cs
 * part of zaaReloaded2
 * 
 * Copyright 2015 Daniel Kraus
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Text;

namespace zaaReloaded2.Formatter
{
    /// <summary>
    /// Defines styling for abnormal laboratory values
    /// </summary>
    [Flags]
    public enum AbnormalStyle
    {
        [Description("Keine Auszeichnung")]
        None = 0x00,

        [Description("Fett")]
        Bold = 0x01,

        [Description("Kursiv")]
        Italics = 0x02,

        [Description("Unterstrichen")]
        Underline = 0x04
    }

    public static class AbnormalStyleExtensions
    {
        /// <summary>
        /// Converts an AbnormalStyle value to textual markup.
        /// </summary>
        /// <param name="style">AbnormalStyle value.</param>
        /// <param name="close">Indicates whether to return an opening or a closing
        /// tag.</param>
        /// <returns>Markup that is understood by a DocumentWriter.</returns>
        public static string ToMarkup(this AbnormalStyle style, bool close)
        {
            string markup = String.Empty;
            string dash = close ? "/" : String.Empty;
            if (style.HasFlag(AbnormalStyle.Bold))
                markup += String.Format("<{0}b>", dash);
            if (style.HasFlag(AbnormalStyle.Italics))
                markup += String.Format("<{0}i>", dash);
            if (style.HasFlag(AbnormalStyle.Underline))
                markup += String.Format("<{0}u>", dash);
            return markup;
        }
    }
}
