﻿/* PreferencesViewModel.cs
 * part of zaaReloaded2
 * 
 * Copyright 2015 Daniel Kraus
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Bovender.Mvvm;
using Bovender.Mvvm.ViewModels;

namespace zaaReloaded2.ViewModels
{
    /// <summary>
    /// View model for zaaReloaded2.Preferences.
    /// </summary>
    public class PreferencesViewModel : ViewModelBase
    {
        #region Singleton

        public static PreferencesViewModel Default
        {
            get
            {
                return _instance;
            }
        }

        static PreferencesViewModel() { }

        static readonly PreferencesViewModel _instance = new PreferencesViewModel();

        #endregion

        #region Properties

        public bool SuppressItemCommentInteraction { get; set; }

        #endregion

        #region Command

        public DelegatingCommand SaveCommand
        {
            get
            {
                if (_saveCommand == null)
                {
                    _saveCommand = new DelegatingCommand(
                        param => DoSave(),
                        param => CanSave());
                }
                return _saveCommand;
            }
        }

        #endregion

        #region Constructor

        public PreferencesViewModel()
        {
            SuppressItemCommentInteraction = Preferences.Default.SuppressItemCommentInteraction;
        }

        #endregion

        #region Private methods

        void DoSave()
        {
            Preferences.Default.SuppressItemCommentInteraction = SuppressItemCommentInteraction;
            DoCloseView();
        }

        bool CanSave()
        {
            return true;
        }

        #endregion

        #region Field

        DelegatingCommand _saveCommand;

        #endregion

        #region ViewModelBase implementation

        public override object RevealModelObject()
        {
            throw new NotImplementedException();
        }

        #endregion
    }
}
